@@ -1,5 +1,6 @@
 from urllib3.util.retry import Retry
 from .discovery.auth.discovery import Discovery as AuthDiscovery
+from .discovery.automation.discovery import Discovery as AutomationDiscovery
 from .discovery.crm.discovery import Discovery as CrmDiscovery
 from .discovery.cms.discovery import Discovery as CmsDiscovery
 from .discovery.webhooks.discovery import Discovery as WebhooksDiscovery
@@ -41,6 +42,10 @@ class Client:
     def auth(self):
         return AuthDiscovery(self.config)
 
+    @property
+    def automation(self):
+        return AutomationDiscovery(self.config)
+
     @property
     def cms(self):
         return CmsDiscovery(self.config)
